@@ -13,7 +13,7 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
 from offlineimap import threadutil, mbnames, CustomConfig
 import offlineimap.repository.Base, offlineimap.repository.LocalStatus
@@ -191,10 +191,12 @@ def syncfolder(accountname, remoterepos, remotefolder, localrepos,
         if not localfolder.isuidvalidityok():
             ui.validityproblem(localfolder, localfolder.getsaveduidvalidity(),
                                localfolder.getuidvalidity())
+	    localrepos.restore_atime()
             return
         if not remotefolder.isuidvalidityok():
             ui.validityproblem(remotefolder, remotefolder.getsaveduidvalidity(),
                                remotefolder.getuidvalidity())
+	    localrepos.restore_atime()
             return
     else:
         localfolder.saveuidvalidity()
@@ -230,4 +232,5 @@ def syncfolder(accountname, remoterepos, remotefolder, localrepos,
     ui.syncingmessages(localrepos, localfolder, statusrepos, statusfolder)
     localfolder.syncmessagesto(statusfolder)
     statusfolder.save()
+    localrepos.restore_atime()
 
