@@ -1,5 +1,5 @@
 # Base repository support
-# Copyright (C) 2002, 2003 John Goerzen
+# Copyright (C) 2002, 2003, 2006 John Goerzen
 # <jgoerzen@complete.org>
 #
 #    This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
 from offlineimap import CustomConfig
 import os.path
@@ -51,6 +51,18 @@ class BaseRepository(CustomConfig.ConfigHelperMixin):
         if not os.path.exists(self.uiddir):
             os.mkdir(self.uiddir, 0700)
 
+    # The 'restoreatime' config parameter only applies to local Maildir
+    # mailboxes.
+    def restore_atime(self):
+	if self.config.get('Repository ' + self.name, 'type').strip() != \
+		'Maildir':
+	    return
+
+	if not self.config.has_option('Repository ' + self.name, 'restoreatime') or not self.config.getboolean('Repository ' + self.name, 'restoreatime'):
+	    return
+
+	return self.restore_folder_atimes()
+
     def holdordropconnections(self):
         pass
 
