@@ -14,7 +14,7 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
 from __future__ import nested_scopes
 
@@ -246,6 +246,13 @@ class VerboseUI(UIBase):
                 tf = s.availablethreadframes.pop()
                 tf.destroy()
             s.tflock.release()
+
+    def terminate(s, exitstatus = 0, errortitle = None, errormsg = None):
+        if errormsg <> None:
+            if errortitle == None:
+                errortitle = "Error"
+            TextOKDialog(errortitle, errormsg)
+        UIBase.terminate(s, exitstatus = exitstatus, errortitle = None, errormsg = None)
             
     def threadException(s, thread):
         exceptionstr = s.getThreadExceptionString(thread)
@@ -265,7 +272,7 @@ class VerboseUI(UIBase):
         s.top = None
         TextOKDialog("Main Program Exception", exceptionstr)
 
-    def warn(s, msg, minor):
+    def warn(s, msg, minor = 0):
         if minor:
             # Just let the default handler catch it
             UIBase.warn(s, msg, minor)
